# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import authentication_pb2 as authentication__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2


class AuthenticationStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StartPhoneAuth = channel.unary_unary(
                '/dialog.Authentication/StartPhoneAuth',
                request_serializer=authentication__pb2.RequestStartPhoneAuth.SerializeToString,
                response_deserializer=authentication__pb2.ResponseStartPhoneAuth.FromString,
                )
        self.SendCodeByPhoneCall = channel.unary_unary(
                '/dialog.Authentication/SendCodeByPhoneCall',
                request_serializer=authentication__pb2.RequestSendCodeByPhoneCall.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.StartEmailAuth = channel.unary_unary(
                '/dialog.Authentication/StartEmailAuth',
                request_serializer=authentication__pb2.RequestStartEmailAuth.SerializeToString,
                response_deserializer=authentication__pb2.ResponseStartEmailAuth.FromString,
                )
        self.StartAnonymousAuth = channel.unary_unary(
                '/dialog.Authentication/StartAnonymousAuth',
                request_serializer=authentication__pb2.RequestStartAnonymousAuth.SerializeToString,
                response_deserializer=authentication__pb2.ResponseAuth.FromString,
                )
        self.StartTokenAuth = channel.unary_unary(
                '/dialog.Authentication/StartTokenAuth',
                request_serializer=authentication__pb2.RequestStartTokenAuth.SerializeToString,
                response_deserializer=authentication__pb2.ResponseAuth.FromString,
                )
        self.StartUsernameAuth = channel.unary_unary(
                '/dialog.Authentication/StartUsernameAuth',
                request_serializer=authentication__pb2.RequestStartUsernameAuth.SerializeToString,
                response_deserializer=authentication__pb2.ResponseStartUsernameAuth.FromString,
                )
        self.StartAuthTransaction = channel.unary_unary(
                '/dialog.Authentication/StartAuthTransaction',
                request_serializer=authentication__pb2.RequestStartAuthTransaction.SerializeToString,
                response_deserializer=authentication__pb2.ResponseStartAuthTransaction.FromString,
                )
        self.ValidateCode = channel.unary_unary(
                '/dialog.Authentication/ValidateCode',
                request_serializer=authentication__pb2.RequestValidateCode.SerializeToString,
                response_deserializer=authentication__pb2.ResponseAuth.FromString,
                )
        self.ResendCode = channel.unary_unary(
                '/dialog.Authentication/ResendCode',
                request_serializer=authentication__pb2.RequestResendCode.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.ValidatePassword = channel.unary_unary(
                '/dialog.Authentication/ValidatePassword',
                request_serializer=authentication__pb2.RequestValidatePassword.SerializeToString,
                response_deserializer=authentication__pb2.ResponseAuth.FromString,
                )
        self.GetOAuth2Params = channel.unary_unary(
                '/dialog.Authentication/GetOAuth2Params',
                request_serializer=authentication__pb2.RequestGetOAuth2Params.SerializeToString,
                response_deserializer=authentication__pb2.ResponseGetOAuth2Params.FromString,
                )
        self.CompleteOAuth2 = channel.unary_unary(
                '/dialog.Authentication/CompleteOAuth2',
                request_serializer=authentication__pb2.RequestCompleteOAuth2.SerializeToString,
                response_deserializer=authentication__pb2.ResponseAuth.FromString,
                )
        self.SignUp = channel.unary_unary(
                '/dialog.Authentication/SignUp',
                request_serializer=authentication__pb2.RequestSignUp.SerializeToString,
                response_deserializer=authentication__pb2.ResponseAuth.FromString,
                )
        self.GetAuthSessions = channel.unary_unary(
                '/dialog.Authentication/GetAuthSessions',
                request_serializer=authentication__pb2.RequestGetAuthSessions.SerializeToString,
                response_deserializer=authentication__pb2.ResponseGetAuthSessions.FromString,
                )
        self.TerminateSession = channel.unary_unary(
                '/dialog.Authentication/TerminateSession',
                request_serializer=authentication__pb2.RequestTerminateSession.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.TerminateAllSessions = channel.unary_unary(
                '/dialog.Authentication/TerminateAllSessions',
                request_serializer=authentication__pb2.RequestTerminateAllSessions.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.SignOut = channel.unary_unary(
                '/dialog.Authentication/SignOut',
                request_serializer=authentication__pb2.RequestSignOut.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.SignInObsolete = channel.unary_unary(
                '/dialog.Authentication/SignInObsolete',
                request_serializer=authentication__pb2.RequestSignInObsolete.SerializeToString,
                response_deserializer=authentication__pb2.ResponseAuth.FromString,
                )
        self.SignUpObsolete = channel.unary_unary(
                '/dialog.Authentication/SignUpObsolete',
                request_serializer=authentication__pb2.RequestSignUpObsolete.SerializeToString,
                response_deserializer=authentication__pb2.ResponseAuth.FromString,
                )
        self.SendAuthCodeObsolete = channel.unary_unary(
                '/dialog.Authentication/SendAuthCodeObsolete',
                request_serializer=authentication__pb2.RequestSendAuthCodeObsolete.SerializeToString,
                response_deserializer=authentication__pb2.ResponseSendAuthCodeObsolete.FromString,
                )
        self.SendAuthCallObsolete = channel.unary_unary(
                '/dialog.Authentication/SendAuthCallObsolete',
                request_serializer=authentication__pb2.RequestSendAuthCallObsolete.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.ChangePassword = channel.unary_unary(
                '/dialog.Authentication/ChangePassword',
                request_serializer=authentication__pb2.RequestChangePassword.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.GetSelf = channel.unary_unary(
                '/dialog.Authentication/GetSelf',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=authentication__pb2.ResponseGetSelf.FromString,
                )


class AuthenticationServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StartPhoneAuth(self, request, context):
        """/ Start authorization by phone
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendCodeByPhoneCall(self, request, context):
        """/ Resend code by transaction hash
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartEmailAuth(self, request, context):
        """/ Start email authorization process
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartAnonymousAuth(self, request, context):
        """/ Deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartTokenAuth(self, request, context):
        """/ Start token auth authorization (actual for bots)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartUsernameAuth(self, request, context):
        """/ Start login/password authorization process
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartAuthTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateCode(self, request, context):
        """* Validate code received by phone or email
        Returns error if user does not exist
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResendCode(self, request, context):
        """/ Resend code if you don't receive it with first attempt
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidatePassword(self, request, context):
        """/ Validate your passwword
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOAuth2Params(self, request, context):
        """/ Get redirect url
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompleteOAuth2(self, request, context):
        """/ Complete OAuth2 Authentication
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SignUp(self, request, context):
        """/ Sign up existed user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAuthSessions(self, request, context):
        """/ Returns all authorized user's sessions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TerminateSession(self, request, context):
        """/ Deprecated. Does not produce any effect.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TerminateAllSessions(self, request, context):
        """/ Log out user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SignOut(self, request, context):
        """/ Log out current session
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SignInObsolete(self, request, context):
        """/ Deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SignUpObsolete(self, request, context):
        """/ Deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendAuthCodeObsolete(self, request, context):
        """/ Deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendAuthCallObsolete(self, request, context):
        """/ Deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangePassword(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSelf(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthenticationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StartPhoneAuth': grpc.unary_unary_rpc_method_handler(
                    servicer.StartPhoneAuth,
                    request_deserializer=authentication__pb2.RequestStartPhoneAuth.FromString,
                    response_serializer=authentication__pb2.ResponseStartPhoneAuth.SerializeToString,
            ),
            'SendCodeByPhoneCall': grpc.unary_unary_rpc_method_handler(
                    servicer.SendCodeByPhoneCall,
                    request_deserializer=authentication__pb2.RequestSendCodeByPhoneCall.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'StartEmailAuth': grpc.unary_unary_rpc_method_handler(
                    servicer.StartEmailAuth,
                    request_deserializer=authentication__pb2.RequestStartEmailAuth.FromString,
                    response_serializer=authentication__pb2.ResponseStartEmailAuth.SerializeToString,
            ),
            'StartAnonymousAuth': grpc.unary_unary_rpc_method_handler(
                    servicer.StartAnonymousAuth,
                    request_deserializer=authentication__pb2.RequestStartAnonymousAuth.FromString,
                    response_serializer=authentication__pb2.ResponseAuth.SerializeToString,
            ),
            'StartTokenAuth': grpc.unary_unary_rpc_method_handler(
                    servicer.StartTokenAuth,
                    request_deserializer=authentication__pb2.RequestStartTokenAuth.FromString,
                    response_serializer=authentication__pb2.ResponseAuth.SerializeToString,
            ),
            'StartUsernameAuth': grpc.unary_unary_rpc_method_handler(
                    servicer.StartUsernameAuth,
                    request_deserializer=authentication__pb2.RequestStartUsernameAuth.FromString,
                    response_serializer=authentication__pb2.ResponseStartUsernameAuth.SerializeToString,
            ),
            'StartAuthTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.StartAuthTransaction,
                    request_deserializer=authentication__pb2.RequestStartAuthTransaction.FromString,
                    response_serializer=authentication__pb2.ResponseStartAuthTransaction.SerializeToString,
            ),
            'ValidateCode': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateCode,
                    request_deserializer=authentication__pb2.RequestValidateCode.FromString,
                    response_serializer=authentication__pb2.ResponseAuth.SerializeToString,
            ),
            'ResendCode': grpc.unary_unary_rpc_method_handler(
                    servicer.ResendCode,
                    request_deserializer=authentication__pb2.RequestResendCode.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'ValidatePassword': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidatePassword,
                    request_deserializer=authentication__pb2.RequestValidatePassword.FromString,
                    response_serializer=authentication__pb2.ResponseAuth.SerializeToString,
            ),
            'GetOAuth2Params': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOAuth2Params,
                    request_deserializer=authentication__pb2.RequestGetOAuth2Params.FromString,
                    response_serializer=authentication__pb2.ResponseGetOAuth2Params.SerializeToString,
            ),
            'CompleteOAuth2': grpc.unary_unary_rpc_method_handler(
                    servicer.CompleteOAuth2,
                    request_deserializer=authentication__pb2.RequestCompleteOAuth2.FromString,
                    response_serializer=authentication__pb2.ResponseAuth.SerializeToString,
            ),
            'SignUp': grpc.unary_unary_rpc_method_handler(
                    servicer.SignUp,
                    request_deserializer=authentication__pb2.RequestSignUp.FromString,
                    response_serializer=authentication__pb2.ResponseAuth.SerializeToString,
            ),
            'GetAuthSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAuthSessions,
                    request_deserializer=authentication__pb2.RequestGetAuthSessions.FromString,
                    response_serializer=authentication__pb2.ResponseGetAuthSessions.SerializeToString,
            ),
            'TerminateSession': grpc.unary_unary_rpc_method_handler(
                    servicer.TerminateSession,
                    request_deserializer=authentication__pb2.RequestTerminateSession.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'TerminateAllSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.TerminateAllSessions,
                    request_deserializer=authentication__pb2.RequestTerminateAllSessions.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'SignOut': grpc.unary_unary_rpc_method_handler(
                    servicer.SignOut,
                    request_deserializer=authentication__pb2.RequestSignOut.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'SignInObsolete': grpc.unary_unary_rpc_method_handler(
                    servicer.SignInObsolete,
                    request_deserializer=authentication__pb2.RequestSignInObsolete.FromString,
                    response_serializer=authentication__pb2.ResponseAuth.SerializeToString,
            ),
            'SignUpObsolete': grpc.unary_unary_rpc_method_handler(
                    servicer.SignUpObsolete,
                    request_deserializer=authentication__pb2.RequestSignUpObsolete.FromString,
                    response_serializer=authentication__pb2.ResponseAuth.SerializeToString,
            ),
            'SendAuthCodeObsolete': grpc.unary_unary_rpc_method_handler(
                    servicer.SendAuthCodeObsolete,
                    request_deserializer=authentication__pb2.RequestSendAuthCodeObsolete.FromString,
                    response_serializer=authentication__pb2.ResponseSendAuthCodeObsolete.SerializeToString,
            ),
            'SendAuthCallObsolete': grpc.unary_unary_rpc_method_handler(
                    servicer.SendAuthCallObsolete,
                    request_deserializer=authentication__pb2.RequestSendAuthCallObsolete.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'ChangePassword': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangePassword,
                    request_deserializer=authentication__pb2.RequestChangePassword.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'GetSelf': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSelf,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=authentication__pb2.ResponseGetSelf.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Authentication', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Authentication(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StartPhoneAuth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/StartPhoneAuth',
            authentication__pb2.RequestStartPhoneAuth.SerializeToString,
            authentication__pb2.ResponseStartPhoneAuth.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendCodeByPhoneCall(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/SendCodeByPhoneCall',
            authentication__pb2.RequestSendCodeByPhoneCall.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartEmailAuth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/StartEmailAuth',
            authentication__pb2.RequestStartEmailAuth.SerializeToString,
            authentication__pb2.ResponseStartEmailAuth.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartAnonymousAuth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/StartAnonymousAuth',
            authentication__pb2.RequestStartAnonymousAuth.SerializeToString,
            authentication__pb2.ResponseAuth.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartTokenAuth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/StartTokenAuth',
            authentication__pb2.RequestStartTokenAuth.SerializeToString,
            authentication__pb2.ResponseAuth.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartUsernameAuth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/StartUsernameAuth',
            authentication__pb2.RequestStartUsernameAuth.SerializeToString,
            authentication__pb2.ResponseStartUsernameAuth.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartAuthTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/StartAuthTransaction',
            authentication__pb2.RequestStartAuthTransaction.SerializeToString,
            authentication__pb2.ResponseStartAuthTransaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/ValidateCode',
            authentication__pb2.RequestValidateCode.SerializeToString,
            authentication__pb2.ResponseAuth.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResendCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/ResendCode',
            authentication__pb2.RequestResendCode.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidatePassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/ValidatePassword',
            authentication__pb2.RequestValidatePassword.SerializeToString,
            authentication__pb2.ResponseAuth.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOAuth2Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/GetOAuth2Params',
            authentication__pb2.RequestGetOAuth2Params.SerializeToString,
            authentication__pb2.ResponseGetOAuth2Params.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CompleteOAuth2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/CompleteOAuth2',
            authentication__pb2.RequestCompleteOAuth2.SerializeToString,
            authentication__pb2.ResponseAuth.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SignUp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/SignUp',
            authentication__pb2.RequestSignUp.SerializeToString,
            authentication__pb2.ResponseAuth.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAuthSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/GetAuthSessions',
            authentication__pb2.RequestGetAuthSessions.SerializeToString,
            authentication__pb2.ResponseGetAuthSessions.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TerminateSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/TerminateSession',
            authentication__pb2.RequestTerminateSession.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TerminateAllSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/TerminateAllSessions',
            authentication__pb2.RequestTerminateAllSessions.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SignOut(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/SignOut',
            authentication__pb2.RequestSignOut.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SignInObsolete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/SignInObsolete',
            authentication__pb2.RequestSignInObsolete.SerializeToString,
            authentication__pb2.ResponseAuth.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SignUpObsolete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/SignUpObsolete',
            authentication__pb2.RequestSignUpObsolete.SerializeToString,
            authentication__pb2.ResponseAuth.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendAuthCodeObsolete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/SendAuthCodeObsolete',
            authentication__pb2.RequestSendAuthCodeObsolete.SerializeToString,
            authentication__pb2.ResponseSendAuthCodeObsolete.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendAuthCallObsolete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/SendAuthCallObsolete',
            authentication__pb2.RequestSendAuthCallObsolete.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangePassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/ChangePassword',
            authentication__pb2.RequestChangePassword.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSelf(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Authentication/GetSelf',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            authentication__pb2.ResponseGetSelf.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import miscellaneous_pb2 as miscellaneous__pb2
from . import push_pb2 as push__pb2


class PushStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RegisterGooglePush = channel.unary_unary(
                '/dialog.Push/RegisterGooglePush',
                request_serializer=push__pb2.RequestRegisterGooglePush.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.UnregisterGooglePush = channel.unary_unary(
                '/dialog.Push/UnregisterGooglePush',
                request_serializer=push__pb2.RequestUnregisterGooglePush.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.RegisterApplePush = channel.unary_unary(
                '/dialog.Push/RegisterApplePush',
                request_serializer=push__pb2.RequestRegisterApplePush.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.UnregisterApplePush = channel.unary_unary(
                '/dialog.Push/UnregisterApplePush',
                request_serializer=push__pb2.RequestUnregisterApplePush.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.RegisterApplePushKit = channel.unary_unary(
                '/dialog.Push/RegisterApplePushKit',
                request_serializer=push__pb2.RequestRegisterApplePushKit.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.UnregisterApplePushKit = channel.unary_unary(
                '/dialog.Push/UnregisterApplePushKit',
                request_serializer=push__pb2.RequestUnregisterApplePushKit.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.RegisterApplePushToken = channel.unary_unary(
                '/dialog.Push/RegisterApplePushToken',
                request_serializer=push__pb2.RequestRegisterApplePushToken.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.UnregisterApplePushToken = channel.unary_unary(
                '/dialog.Push/UnregisterApplePushToken',
                request_serializer=push__pb2.RequestUnregisterApplePushToken.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.RegisterAvroraPushToken = channel.unary_unary(
                '/dialog.Push/RegisterAvroraPushToken',
                request_serializer=push__pb2.RequestRegisterAvroraPushToken.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.UnregisterAvroraPushToken = channel.unary_unary(
                '/dialog.Push/UnregisterAvroraPushToken',
                request_serializer=push__pb2.RequestUnregisterAvroraPushToken.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )


class PushServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RegisterGooglePush(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnregisterGooglePush(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterApplePush(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnregisterApplePush(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterApplePushKit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnregisterApplePushKit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterApplePushToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnregisterApplePushToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterAvroraPushToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnregisterAvroraPushToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PushServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RegisterGooglePush': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterGooglePush,
                    request_deserializer=push__pb2.RequestRegisterGooglePush.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'UnregisterGooglePush': grpc.unary_unary_rpc_method_handler(
                    servicer.UnregisterGooglePush,
                    request_deserializer=push__pb2.RequestUnregisterGooglePush.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'RegisterApplePush': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterApplePush,
                    request_deserializer=push__pb2.RequestRegisterApplePush.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'UnregisterApplePush': grpc.unary_unary_rpc_method_handler(
                    servicer.UnregisterApplePush,
                    request_deserializer=push__pb2.RequestUnregisterApplePush.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'RegisterApplePushKit': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterApplePushKit,
                    request_deserializer=push__pb2.RequestRegisterApplePushKit.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'UnregisterApplePushKit': grpc.unary_unary_rpc_method_handler(
                    servicer.UnregisterApplePushKit,
                    request_deserializer=push__pb2.RequestUnregisterApplePushKit.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'RegisterApplePushToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterApplePushToken,
                    request_deserializer=push__pb2.RequestRegisterApplePushToken.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'UnregisterApplePushToken': grpc.unary_unary_rpc_method_handler(
                    servicer.UnregisterApplePushToken,
                    request_deserializer=push__pb2.RequestUnregisterApplePushToken.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'RegisterAvroraPushToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterAvroraPushToken,
                    request_deserializer=push__pb2.RequestRegisterAvroraPushToken.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'UnregisterAvroraPushToken': grpc.unary_unary_rpc_method_handler(
                    servicer.UnregisterAvroraPushToken,
                    request_deserializer=push__pb2.RequestUnregisterAvroraPushToken.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Push', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Push(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RegisterGooglePush(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/RegisterGooglePush',
            push__pb2.RequestRegisterGooglePush.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnregisterGooglePush(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/UnregisterGooglePush',
            push__pb2.RequestUnregisterGooglePush.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterApplePush(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/RegisterApplePush',
            push__pb2.RequestRegisterApplePush.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnregisterApplePush(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/UnregisterApplePush',
            push__pb2.RequestUnregisterApplePush.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterApplePushKit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/RegisterApplePushKit',
            push__pb2.RequestRegisterApplePushKit.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnregisterApplePushKit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/UnregisterApplePushKit',
            push__pb2.RequestUnregisterApplePushKit.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterApplePushToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/RegisterApplePushToken',
            push__pb2.RequestRegisterApplePushToken.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnregisterApplePushToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/UnregisterApplePushToken',
            push__pb2.RequestUnregisterApplePushToken.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterAvroraPushToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/RegisterAvroraPushToken',
            push__pb2.RequestRegisterAvroraPushToken.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnregisterAvroraPushToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/UnregisterAvroraPushToken',
            push__pb2.RequestUnregisterAvroraPushToken.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: crypto.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='crypto.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0c\x63rypto.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x15scalapb/scalapb.proto\"r\n\x12RequestKeyExchange\x12>\n\nclient_key\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.BytesValueB\r\x8a\xea\x30\t\n\x07\x63ompact:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"e\n\x13ResponseKeyExchange\x12/\n\nserver_key\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.BytesValue:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse2x\n\x06\x43rypto\x12n\n\x0bKeyExchange\x12\x1a.dialog.RequestKeyExchange\x1a\x1b.dialog.ResponseKeyExchange\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/grpc/Crypto/KeyExchange:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_REQUESTKEYEXCHANGE = _descriptor.Descriptor(
  name='RequestKeyExchange',
  full_name='dialog.RequestKeyExchange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_key', full_name='dialog.RequestKeyExchange.client_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=242,
)


_RESPONSEKEYEXCHANGE = _descriptor.Descriptor(
  name='ResponseKeyExchange',
  full_name='dialog.ResponseKeyExchange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_key', full_name='dialog.ResponseKeyExchange.server_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=345,
)

_REQUESTKEYEXCHANGE.fields_by_name['client_key'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_RESPONSEKEYEXCHANGE.fields_by_name['server_key'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
DESCRIPTOR.message_types_by_name['RequestKeyExchange'] = _REQUESTKEYEXCHANGE
DESCRIPTOR.message_types_by_name['ResponseKeyExchange'] = _RESPONSEKEYEXCHANGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestKeyExchange = _reflection.GeneratedProtocolMessageType('RequestKeyExchange', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTKEYEXCHANGE,
  '__module__' : 'crypto_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestKeyExchange)
  })
_sym_db.RegisterMessage(RequestKeyExchange)

ResponseKeyExchange = _reflection.GeneratedProtocolMessageType('ResponseKeyExchange', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEKEYEXCHANGE,
  '__module__' : 'crypto_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseKeyExchange)
  })
_sym_db.RegisterMessage(ResponseKeyExchange)


DESCRIPTOR._options = None
_REQUESTKEYEXCHANGE.fields_by_name['client_key']._options = None
_REQUESTKEYEXCHANGE._options = None
_RESPONSEKEYEXCHANGE._options = None

_CRYPTO = _descriptor.ServiceDescriptor(
  name='Crypto',
  full_name='dialog.Crypto',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=347,
  serialized_end=467,
  methods=[
  _descriptor.MethodDescriptor(
    name='KeyExchange',
    full_name='dialog.Crypto.KeyExchange',
    index=0,
    containing_service=None,
    input_type=_REQUESTKEYEXCHANGE,
    output_type=_RESPONSEKEYEXCHANGE,
    serialized_options=b'\202\323\344\223\002 \"\033/v1/grpc/Crypto/KeyExchange:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CRYPTO)

DESCRIPTOR.services_by_name['Crypto'] = _CRYPTO

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: contacts.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from . import peers_pb2 as peers__pb2
from . import users_pb2 as users__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='contacts.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0e\x63ontacts.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x0bpeers.proto\x1a\x0busers.proto\x1a\x15scalapb/scalapb.proto\"o\n\rPhoneToImport\x12#\n\x0cphone_number\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\"h\n\rEmailToImport\x12\x1c\n\x05\x65mail\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\"\xe3\x01\n\x15RequestImportContacts\x12\x34\n\x06phones\x18\x01 \x03(\x0b\x32\x15.dialog.PhoneToImportB\r\x8a\xea\x30\t\n\x07\x63ompact\x12\x34\n\x06\x65mails\x18\x02 \x03(\x0b\x32\x15.dialog.EmailToImportB\r\x8a\xea\x30\t\n\x07\x63ompact\x12@\n\roptimizations\x18\x03 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x82\x01\n\x16ResponseImportContacts\x12\x0b\n\x03seq\x18\x02 \x01(\x05\x12\r\n\x05state\x18\x03 \x01(\x0c\x12\'\n\nuser_peers\x18\x04 \x03(\x0b\x32\x13.dialog.UserOutPeer:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponseJ\x04\x08\x01\x10\x02\"\xa9\x01\n\x1dRequestDeferredImportContacts\x12\x34\n\x06phones\x18\x01 \x03(\x0b\x32\x15.dialog.PhoneToImportB\r\x8a\xea\x30\t\n\x07\x63ompact\x12\x34\n\x06\x65mails\x18\x02 \x03(\x0b\x32\x15.dialog.EmailToImportB\r\x8a\xea\x30\t\n\x07\x63ompact:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"P\n\x1eResponseDeferredImportContacts\x12\x0f\n\x07task_id\x18\x01 \x01(\t:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\x9a\x01\n\x12RequestGetContacts\x12$\n\rcontacts_hash\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12@\n\roptimizations\x18\x02 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"{\n\x13ResponseGetContacts\x12\x16\n\x0eis_not_changed\x18\x02 \x01(\x08\x12\'\n\nuser_peers\x18\x03 \x03(\x0b\x32\x13.dialog.UserOutPeer:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponseJ\x04\x08\x01\x10\x02\"s\n\x14RequestRemoveContact\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\x0b\x61\x63\x63\x65ss_hash\x18\x02 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"p\n\x11RequestAddContact\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\x0b\x61\x63\x63\x65ss_hash\x18\x02 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x88\x01\n\x15RequestSearchContacts\x12\x1e\n\x07request\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x31\n\roptimizations\x18\x02 \x03(\x0e\x32\x1a.dialog.UpdateOptimization:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"}\n\x16ResponseSearchContacts\x12\x1b\n\x05users\x18\x01 \x03(\x0b\x32\x0c.dialog.User\x12\'\n\nuser_peers\x18\x02 \x03(\x0b\x32\x13.dialog.UserOutPeer:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xa3\x01\n\x17UpdateContactRegistered\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\tis_silent\x18\x02 \x01(\x08\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12-\n\x03mid\x18\x05 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\"p\n\x13UpdateContactsAdded\x12\x1b\n\x04uids\x18\x01 \x03(\x05\x42\r\x8a\xea\x30\t\n\x07\x63ompact\x12<\n\x07task_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07\x63ompact\"@\n\x1eUpdateContactsAddTaskSuspended\x12\x1e\n\x07task_id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07\x63ompact\"4\n\x15UpdateContactsRemoved\x12\x1b\n\x04uids\x18\x01 \x03(\x05\x42\r\x8a\xea\x30\t\n\x07\x63ompact2\xee\x05\n\x08\x43ontacts\x12|\n\x0eImportContacts\x12\x1d.dialog.RequestImportContacts\x1a\x1e.dialog.ResponseImportContacts\"+\x82\xd3\xe4\x93\x02%\" /v1/grpc/Contacts/ImportContacts:\x01*\x12\x9c\x01\n\x16\x44\x65\x66\x65rredImportContacts\x12%.dialog.RequestDeferredImportContacts\x1a&.dialog.ResponseDeferredImportContacts\"3\x82\xd3\xe4\x93\x02-\"(/v1/grpc/Contacts/DeferredImportContacts:\x01*\x12p\n\x0bGetContacts\x12\x1a.dialog.RequestGetContacts\x1a\x1b.dialog.ResponseGetContacts\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/grpc/Contacts/GetContacts:\x01*\x12n\n\rRemoveContact\x12\x1c.dialog.RequestRemoveContact\x1a\x13.dialog.ResponseSeq\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/grpc/Contacts/RemoveContact:\x01*\x12\x65\n\nAddContact\x12\x19.dialog.RequestAddContact\x1a\x13.dialog.ResponseSeq\"\'\x82\xd3\xe4\x93\x02!\"\x1c/v1/grpc/Contacts/AddContact:\x01*\x12|\n\x0eSearchContacts\x12\x1d.dialog.RequestSearchContacts\x1a\x1e.dialog.ResponseSearchContacts\"+\x82\xd3\xe4\x93\x02%\" /v1/grpc/Contacts/SearchContacts:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,users__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_PHONETOIMPORT = _descriptor.Descriptor(
  name='PhoneToImport',
  full_name='dialog.PhoneToImport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='dialog.PhoneToImport.phone_number', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='dialog.PhoneToImport.name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=288,
)


_EMAILTOIMPORT = _descriptor.Descriptor(
  name='EmailToImport',
  full_name='dialog.EmailToImport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='dialog.EmailToImport.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='dialog.EmailToImport.name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=290,
  serialized_end=394,
)


_REQUESTIMPORTCONTACTS = _descriptor.Descriptor(
  name='RequestImportContacts',
  full_name='dialog.RequestImportContacts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='phones', full_name='dialog.RequestImportContacts.phones', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='emails', full_name='dialog.RequestImportContacts.emails', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestImportContacts.optimizations', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=624,
)


_RESPONSEIMPORTCONTACTS = _descriptor.Descriptor(
  name='ResponseImportContacts',
  full_name='dialog.ResponseImportContacts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ResponseImportContacts.seq', index=0,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ResponseImportContacts.state', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.ResponseImportContacts.user_peers', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=627,
  serialized_end=757,
)


_REQUESTDEFERREDIMPORTCONTACTS = _descriptor.Descriptor(
  name='RequestDeferredImportContacts',
  full_name='dialog.RequestDeferredImportContacts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='phones', full_name='dialog.RequestDeferredImportContacts.phones', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='emails', full_name='dialog.RequestDeferredImportContacts.emails', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=760,
  serialized_end=929,
)


_RESPONSEDEFERREDIMPORTCONTACTS = _descriptor.Descriptor(
  name='ResponseDeferredImportContacts',
  full_name='dialog.ResponseDeferredImportContacts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_id', full_name='dialog.ResponseDeferredImportContacts.task_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=931,
  serialized_end=1011,
)


_REQUESTGETCONTACTS = _descriptor.Descriptor(
  name='RequestGetContacts',
  full_name='dialog.RequestGetContacts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contacts_hash', full_name='dialog.RequestGetContacts.contacts_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestGetContacts.optimizations', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1014,
  serialized_end=1168,
)


_RESPONSEGETCONTACTS = _descriptor.Descriptor(
  name='ResponseGetContacts',
  full_name='dialog.ResponseGetContacts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_not_changed', full_name='dialog.ResponseGetContacts.is_not_changed', index=0,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.ResponseGetContacts.user_peers', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1170,
  serialized_end=1293,
)


_REQUESTREMOVECONTACT = _descriptor.Descriptor(
  name='RequestRemoveContact',
  full_name='dialog.RequestRemoveContact',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.RequestRemoveContact.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_hash', full_name='dialog.RequestRemoveContact.access_hash', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006danger', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1295,
  serialized_end=1410,
)


_REQUESTADDCONTACT = _descriptor.Descriptor(
  name='RequestAddContact',
  full_name='dialog.RequestAddContact',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.RequestAddContact.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_hash', full_name='dialog.RequestAddContact.access_hash', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006danger', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1412,
  serialized_end=1524,
)


_REQUESTSEARCHCONTACTS = _descriptor.Descriptor(
  name='RequestSearchContacts',
  full_name='dialog.RequestSearchContacts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='dialog.RequestSearchContacts.request', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestSearchContacts.optimizations', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1527,
  serialized_end=1663,
)


_RESPONSESEARCHCONTACTS = _descriptor.Descriptor(
  name='ResponseSearchContacts',
  full_name='dialog.ResponseSearchContacts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.ResponseSearchContacts.users', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.ResponseSearchContacts.user_peers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1665,
  serialized_end=1790,
)


_UPDATECONTACTREGISTERED = _descriptor.Descriptor(
  name='UpdateContactRegistered',
  full_name='dialog.UpdateContactRegistered',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateContactRegistered.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_silent', full_name='dialog.UpdateContactRegistered.is_silent', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateContactRegistered.date', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateContactRegistered.mid', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1793,
  serialized_end=1956,
)


_UPDATECONTACTSADDED = _descriptor.Descriptor(
  name='UpdateContactsAdded',
  full_name='dialog.UpdateContactsAdded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uids', full_name='dialog.UpdateContactsAdded.uids', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_id', full_name='dialog.UpdateContactsAdded.task_id', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1958,
  serialized_end=2070,
)


_UPDATECONTACTSADDTASKSUSPENDED = _descriptor.Descriptor(
  name='UpdateContactsAddTaskSuspended',
  full_name='dialog.UpdateContactsAddTaskSuspended',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_id', full_name='dialog.UpdateContactsAddTaskSuspended.task_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2072,
  serialized_end=2136,
)


_UPDATECONTACTSREMOVED = _descriptor.Descriptor(
  name='UpdateContactsRemoved',
  full_name='dialog.UpdateContactsRemoved',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uids', full_name='dialog.UpdateContactsRemoved.uids', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2138,
  serialized_end=2190,
)

_PHONETOIMPORT.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EMAILTOIMPORT.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTIMPORTCONTACTS.fields_by_name['phones'].message_type = _PHONETOIMPORT
_REQUESTIMPORTCONTACTS.fields_by_name['emails'].message_type = _EMAILTOIMPORT
_REQUESTIMPORTCONTACTS.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_RESPONSEIMPORTCONTACTS.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
_REQUESTDEFERREDIMPORTCONTACTS.fields_by_name['phones'].message_type = _PHONETOIMPORT
_REQUESTDEFERREDIMPORTCONTACTS.fields_by_name['emails'].message_type = _EMAILTOIMPORT
_REQUESTGETCONTACTS.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_RESPONSEGETCONTACTS.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
_REQUESTSEARCHCONTACTS.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_RESPONSESEARCHCONTACTS.fields_by_name['users'].message_type = users__pb2._USER
_RESPONSESEARCHCONTACTS.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
_UPDATECONTACTREGISTERED.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATECONTACTSADDED.fields_by_name['task_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['PhoneToImport'] = _PHONETOIMPORT
DESCRIPTOR.message_types_by_name['EmailToImport'] = _EMAILTOIMPORT
DESCRIPTOR.message_types_by_name['RequestImportContacts'] = _REQUESTIMPORTCONTACTS
DESCRIPTOR.message_types_by_name['ResponseImportContacts'] = _RESPONSEIMPORTCONTACTS
DESCRIPTOR.message_types_by_name['RequestDeferredImportContacts'] = _REQUESTDEFERREDIMPORTCONTACTS
DESCRIPTOR.message_types_by_name['ResponseDeferredImportContacts'] = _RESPONSEDEFERREDIMPORTCONTACTS
DESCRIPTOR.message_types_by_name['RequestGetContacts'] = _REQUESTGETCONTACTS
DESCRIPTOR.message_types_by_name['ResponseGetContacts'] = _RESPONSEGETCONTACTS
DESCRIPTOR.message_types_by_name['RequestRemoveContact'] = _REQUESTREMOVECONTACT
DESCRIPTOR.message_types_by_name['RequestAddContact'] = _REQUESTADDCONTACT
DESCRIPTOR.message_types_by_name['RequestSearchContacts'] = _REQUESTSEARCHCONTACTS
DESCRIPTOR.message_types_by_name['ResponseSearchContacts'] = _RESPONSESEARCHCONTACTS
DESCRIPTOR.message_types_by_name['UpdateContactRegistered'] = _UPDATECONTACTREGISTERED
DESCRIPTOR.message_types_by_name['UpdateContactsAdded'] = _UPDATECONTACTSADDED
DESCRIPTOR.message_types_by_name['UpdateContactsAddTaskSuspended'] = _UPDATECONTACTSADDTASKSUSPENDED
DESCRIPTOR.message_types_by_name['UpdateContactsRemoved'] = _UPDATECONTACTSREMOVED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PhoneToImport = _reflection.GeneratedProtocolMessageType('PhoneToImport', (_message.Message,), {
  'DESCRIPTOR' : _PHONETOIMPORT,
  '__module__' : 'contacts_pb2'
  # @@protoc_insertion_point(class_scope:dialog.PhoneToImport)
  })
_sym_db.RegisterMessage(PhoneToImport)

EmailToImport = _reflection.GeneratedProtocolMessageType('EmailToImport', (_message.Message,), {
  'DESCRIPTOR' : _EMAILTOIMPORT,
  '__module__' : 'contacts_pb2'
  # @@protoc_insertion_point(class_scope:dialog.EmailToImport)
  })
_sym_db.RegisterMessage(EmailToImport)

RequestImportContacts = _reflection.GeneratedProtocolMessageType('RequestImportContacts', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTIMPORTCONTACTS,
  '__module__' : 'contacts_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestImportContacts)
  })
_sym_db.RegisterMessage(RequestImportContacts)

ResponseImportContacts = _reflection.GeneratedProtocolMessageType('ResponseImportContacts', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEIMPORTCONTACTS,
  '__module__' : 'contacts_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseImportContacts)
  })
_sym_db.RegisterMessage(ResponseImportContacts)

RequestDeferredImportContacts = _reflection.GeneratedProtocolMessageType('RequestDeferredImportContacts', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDEFERREDIMPORTCONTACTS,
  '__module__' : 'contacts_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestDeferredImportContacts)
  })
_sym_db.RegisterMessage(RequestDeferredImportContacts)

ResponseDeferredImportContacts = _reflection.GeneratedProtocolMessageType('ResponseDeferredImportContacts', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEDEFERREDIMPORTCONTACTS,
  '__module__' : 'contacts_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseDeferredImportContacts)
  })
_sym_db.RegisterMessage(ResponseDeferredImportContacts)

RequestGetContacts = _reflection.GeneratedProtocolMessageType('RequestGetContacts', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTGETCONTACTS,
  '__module__' : 'contacts_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetContacts)
  })
_sym_db.RegisterMessage(RequestGetContacts)

ResponseGetContacts = _reflection.GeneratedProtocolMessageType('ResponseGetContacts', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEGETCONTACTS,
  '__module__' : 'contacts_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetContacts)
  })
_sym_db.RegisterMessage(ResponseGetContacts)

RequestRemoveContact = _reflection.GeneratedProtocolMessageType('RequestRemoveContact', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTREMOVECONTACT,
  '__module__' : 'contacts_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRemoveContact)
  })
_sym_db.RegisterMessage(RequestRemoveContact)

RequestAddContact = _reflection.GeneratedProtocolMessageType('RequestAddContact', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTADDCONTACT,
  '__module__' : 'contacts_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestAddContact)
  })
_sym_db.RegisterMessage(RequestAddContact)

RequestSearchContacts = _reflection.GeneratedProtocolMessageType('RequestSearchContacts', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSEARCHCONTACTS,
  '__module__' : 'contacts_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSearchContacts)
  })
_sym_db.RegisterMessage(RequestSearchContacts)

ResponseSearchContacts = _reflection.GeneratedProtocolMessageType('ResponseSearchContacts', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSESEARCHCONTACTS,
  '__module__' : 'contacts_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseSearchContacts)
  })
_sym_db.RegisterMessage(ResponseSearchContacts)

UpdateContactRegistered = _reflection.GeneratedProtocolMessageType('UpdateContactRegistered', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONTACTREGISTERED,
  '__module__' : 'contacts_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateContactRegistered)
  })
_sym_db.RegisterMessage(UpdateContactRegistered)

UpdateContactsAdded = _reflection.GeneratedProtocolMessageType('UpdateContactsAdded', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONTACTSADDED,
  '__module__' : 'contacts_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateContactsAdded)
  })
_sym_db.RegisterMessage(UpdateContactsAdded)

UpdateContactsAddTaskSuspended = _reflection.GeneratedProtocolMessageType('UpdateContactsAddTaskSuspended', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONTACTSADDTASKSUSPENDED,
  '__module__' : 'contacts_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateContactsAddTaskSuspended)
  })
_sym_db.RegisterMessage(UpdateContactsAddTaskSuspended)

UpdateContactsRemoved = _reflection.GeneratedProtocolMessageType('UpdateContactsRemoved', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONTACTSREMOVED,
  '__module__' : 'contacts_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateContactsRemoved)
  })
_sym_db.RegisterMessage(UpdateContactsRemoved)


DESCRIPTOR._options = None
_PHONETOIMPORT.fields_by_name['phone_number']._options = None
_PHONETOIMPORT.fields_by_name['name']._options = None
_EMAILTOIMPORT.fields_by_name['email']._options = None
_EMAILTOIMPORT.fields_by_name['name']._options = None
_REQUESTIMPORTCONTACTS.fields_by_name['phones']._options = None
_REQUESTIMPORTCONTACTS.fields_by_name['emails']._options = None
_REQUESTIMPORTCONTACTS.fields_by_name['optimizations']._options = None
_REQUESTIMPORTCONTACTS._options = None
_RESPONSEIMPORTCONTACTS._options = None
_REQUESTDEFERREDIMPORTCONTACTS.fields_by_name['phones']._options = None
_REQUESTDEFERREDIMPORTCONTACTS.fields_by_name['emails']._options = None
_REQUESTDEFERREDIMPORTCONTACTS._options = None
_RESPONSEDEFERREDIMPORTCONTACTS._options = None
_REQUESTGETCONTACTS.fields_by_name['contacts_hash']._options = None
_REQUESTGETCONTACTS.fields_by_name['optimizations']._options = None
_REQUESTGETCONTACTS._options = None
_RESPONSEGETCONTACTS._options = None
_REQUESTREMOVECONTACT.fields_by_name['uid']._options = None
_REQUESTREMOVECONTACT.fields_by_name['access_hash']._options = None
_REQUESTREMOVECONTACT._options = None
_REQUESTADDCONTACT.fields_by_name['uid']._options = None
_REQUESTADDCONTACT.fields_by_name['access_hash']._options = None
_REQUESTADDCONTACT._options = None
_REQUESTSEARCHCONTACTS.fields_by_name['request']._options = None
_REQUESTSEARCHCONTACTS._options = None
_RESPONSESEARCHCONTACTS._options = None
_UPDATECONTACTREGISTERED.fields_by_name['uid']._options = None
_UPDATECONTACTREGISTERED.fields_by_name['is_silent']._options = None
_UPDATECONTACTREGISTERED.fields_by_name['date']._options = None
_UPDATECONTACTREGISTERED.fields_by_name['mid']._options = None
_UPDATECONTACTSADDED.fields_by_name['uids']._options = None
_UPDATECONTACTSADDED.fields_by_name['task_id']._options = None
_UPDATECONTACTSADDTASKSUSPENDED.fields_by_name['task_id']._options = None
_UPDATECONTACTSREMOVED.fields_by_name['uids']._options = None

_CONTACTS = _descriptor.ServiceDescriptor(
  name='Contacts',
  full_name='dialog.Contacts',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2193,
  serialized_end=2943,
  methods=[
  _descriptor.MethodDescriptor(
    name='ImportContacts',
    full_name='dialog.Contacts.ImportContacts',
    index=0,
    containing_service=None,
    input_type=_REQUESTIMPORTCONTACTS,
    output_type=_RESPONSEIMPORTCONTACTS,
    serialized_options=b'\202\323\344\223\002%\" /v1/grpc/Contacts/ImportContacts:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeferredImportContacts',
    full_name='dialog.Contacts.DeferredImportContacts',
    index=1,
    containing_service=None,
    input_type=_REQUESTDEFERREDIMPORTCONTACTS,
    output_type=_RESPONSEDEFERREDIMPORTCONTACTS,
    serialized_options=b'\202\323\344\223\002-\"(/v1/grpc/Contacts/DeferredImportContacts:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetContacts',
    full_name='dialog.Contacts.GetContacts',
    index=2,
    containing_service=None,
    input_type=_REQUESTGETCONTACTS,
    output_type=_RESPONSEGETCONTACTS,
    serialized_options=b'\202\323\344\223\002\"\"\035/v1/grpc/Contacts/GetContacts:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveContact',
    full_name='dialog.Contacts.RemoveContact',
    index=3,
    containing_service=None,
    input_type=_REQUESTREMOVECONTACT,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002$\"\037/v1/grpc/Contacts/RemoveContact:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddContact',
    full_name='dialog.Contacts.AddContact',
    index=4,
    containing_service=None,
    input_type=_REQUESTADDCONTACT,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002!\"\034/v1/grpc/Contacts/AddContact:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SearchContacts',
    full_name='dialog.Contacts.SearchContacts',
    index=5,
    containing_service=None,
    input_type=_REQUESTSEARCHCONTACTS,
    output_type=_RESPONSESEARCHCONTACTS,
    serialized_options=b'\202\323\344\223\002%\" /v1/grpc/Contacts/SearchContacts:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONTACTS)

DESCRIPTOR.services_by_name['Contacts'] = _CONTACTS

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: config_sync.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='config_sync.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11\x63onfig_sync.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x15scalapb/scalapb.proto\"b\n\tParameter\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x05value\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1c\n\x05\x63lock\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"H\n\x14RequestGetParameters\x12\x12\n\nfrom_clock\x18\x01 \x01(\x03:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"]\n\x15ResponseGetParameters\x12%\n\nparameters\x18\x01 \x03(\x0b\x32\x11.dialog.Parameter:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xa9\x01\n\x14RequestEditParameter\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1c\n\x05\x63lock\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"e\n\x0b\x46\x65\x61tureFlag\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05value\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05\x63lock\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"G\n\x13RequestFeatureFlags\x12\x12\n\nfrom_clock\x18\x01 \x01(\x03:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"b\n\x14ResponseFeatureFlags\x12+\n\x0e\x66\x65\x61ture_config\x18\x01 \x03(\x0b\x32\x13.dialog.FeatureFlag:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"O\n\x18UpdateFeatureFlagChanged\x12\x33\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32\x13.dialog.FeatureFlagB\r\x8a\xea\x30\t\n\x07visible\"\x95\x01\n\x16UpdateParameterChanged\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12$\n\tparameter\x18\x03 \x01(\x0b\x32\x11.dialog.Parameter2\xf2\x02\n\nConfigSync\x12z\n\rGetParameters\x12\x1c.dialog.RequestGetParameters\x1a\x1d.dialog.ResponseGetParameters\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/ConfigSync/GetParameters:\x01*\x12p\n\rEditParameter\x12\x1c.dialog.RequestEditParameter\x1a\x13.dialog.ResponseSeq\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/ConfigSync/EditParameter:\x01*\x12v\n\x0c\x46\x65\x61tureFlags\x12\x1b.dialog.RequestFeatureFlags\x1a\x1c.dialog.ResponseFeatureFlags\"+\x82\xd3\xe4\x93\x02%\" /v1/grpc/ConfigSync/FeatureFlags:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_PARAMETER = _descriptor.Descriptor(
  name='Parameter',
  full_name='dialog.Parameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.Parameter.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.Parameter.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.Parameter.clock', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=154,
  serialized_end=252,
)


_REQUESTGETPARAMETERS = _descriptor.Descriptor(
  name='RequestGetParameters',
  full_name='dialog.RequestGetParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_clock', full_name='dialog.RequestGetParameters.from_clock', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=326,
)


_RESPONSEGETPARAMETERS = _descriptor.Descriptor(
  name='ResponseGetParameters',
  full_name='dialog.ResponseGetParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameters', full_name='dialog.ResponseGetParameters.parameters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=421,
)


_REQUESTEDITPARAMETER = _descriptor.Descriptor(
  name='RequestEditParameter',
  full_name='dialog.RequestEditParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.RequestEditParameter.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.RequestEditParameter.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestEditParameter.clock', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=593,
)


_FEATUREFLAG = _descriptor.Descriptor(
  name='FeatureFlag',
  full_name='dialog.FeatureFlag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.FeatureFlag.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.FeatureFlag.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.FeatureFlag.clock', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=595,
  serialized_end=696,
)


_REQUESTFEATUREFLAGS = _descriptor.Descriptor(
  name='RequestFeatureFlags',
  full_name='dialog.RequestFeatureFlags',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_clock', full_name='dialog.RequestFeatureFlags.from_clock', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=698,
  serialized_end=769,
)


_RESPONSEFEATUREFLAGS = _descriptor.Descriptor(
  name='ResponseFeatureFlags',
  full_name='dialog.ResponseFeatureFlags',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_config', full_name='dialog.ResponseFeatureFlags.feature_config', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=771,
  serialized_end=869,
)


_UPDATEFEATUREFLAGCHANGED = _descriptor.Descriptor(
  name='UpdateFeatureFlagChanged',
  full_name='dialog.UpdateFeatureFlagChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature', full_name='dialog.UpdateFeatureFlagChanged.feature', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=871,
  serialized_end=950,
)


_UPDATEPARAMETERCHANGED = _descriptor.Descriptor(
  name='UpdateParameterChanged',
  full_name='dialog.UpdateParameterChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.UpdateParameterChanged.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.UpdateParameterChanged.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='dialog.UpdateParameterChanged.parameter', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=953,
  serialized_end=1102,
)

_RESPONSEGETPARAMETERS.fields_by_name['parameters'].message_type = _PARAMETER
_REQUESTEDITPARAMETER.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSEFEATUREFLAGS.fields_by_name['feature_config'].message_type = _FEATUREFLAG
_UPDATEFEATUREFLAGCHANGED.fields_by_name['feature'].message_type = _FEATUREFLAG
_UPDATEPARAMETERCHANGED.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEPARAMETERCHANGED.fields_by_name['parameter'].message_type = _PARAMETER
DESCRIPTOR.message_types_by_name['Parameter'] = _PARAMETER
DESCRIPTOR.message_types_by_name['RequestGetParameters'] = _REQUESTGETPARAMETERS
DESCRIPTOR.message_types_by_name['ResponseGetParameters'] = _RESPONSEGETPARAMETERS
DESCRIPTOR.message_types_by_name['RequestEditParameter'] = _REQUESTEDITPARAMETER
DESCRIPTOR.message_types_by_name['FeatureFlag'] = _FEATUREFLAG
DESCRIPTOR.message_types_by_name['RequestFeatureFlags'] = _REQUESTFEATUREFLAGS
DESCRIPTOR.message_types_by_name['ResponseFeatureFlags'] = _RESPONSEFEATUREFLAGS
DESCRIPTOR.message_types_by_name['UpdateFeatureFlagChanged'] = _UPDATEFEATUREFLAGCHANGED
DESCRIPTOR.message_types_by_name['UpdateParameterChanged'] = _UPDATEPARAMETERCHANGED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Parameter = _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETER,
  '__module__' : 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Parameter)
  })
_sym_db.RegisterMessage(Parameter)

RequestGetParameters = _reflection.GeneratedProtocolMessageType('RequestGetParameters', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTGETPARAMETERS,
  '__module__' : 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetParameters)
  })
_sym_db.RegisterMessage(RequestGetParameters)

ResponseGetParameters = _reflection.GeneratedProtocolMessageType('ResponseGetParameters', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEGETPARAMETERS,
  '__module__' : 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetParameters)
  })
_sym_db.RegisterMessage(ResponseGetParameters)

RequestEditParameter = _reflection.GeneratedProtocolMessageType('RequestEditParameter', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTEDITPARAMETER,
  '__module__' : 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditParameter)
  })
_sym_db.RegisterMessage(RequestEditParameter)

FeatureFlag = _reflection.GeneratedProtocolMessageType('FeatureFlag', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREFLAG,
  '__module__' : 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.FeatureFlag)
  })
_sym_db.RegisterMessage(FeatureFlag)

RequestFeatureFlags = _reflection.GeneratedProtocolMessageType('RequestFeatureFlags', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTFEATUREFLAGS,
  '__module__' : 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestFeatureFlags)
  })
_sym_db.RegisterMessage(RequestFeatureFlags)

ResponseFeatureFlags = _reflection.GeneratedProtocolMessageType('ResponseFeatureFlags', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEFEATUREFLAGS,
  '__module__' : 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseFeatureFlags)
  })
_sym_db.RegisterMessage(ResponseFeatureFlags)

UpdateFeatureFlagChanged = _reflection.GeneratedProtocolMessageType('UpdateFeatureFlagChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREFLAGCHANGED,
  '__module__' : 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateFeatureFlagChanged)
  })
_sym_db.RegisterMessage(UpdateFeatureFlagChanged)

UpdateParameterChanged = _reflection.GeneratedProtocolMessageType('UpdateParameterChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPARAMETERCHANGED,
  '__module__' : 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateParameterChanged)
  })
_sym_db.RegisterMessage(UpdateParameterChanged)


DESCRIPTOR._options = None
_PARAMETER.fields_by_name['key']._options = None
_PARAMETER.fields_by_name['value']._options = None
_PARAMETER.fields_by_name['clock']._options = None
_REQUESTGETPARAMETERS._options = None
_RESPONSEGETPARAMETERS._options = None
_REQUESTEDITPARAMETER.fields_by_name['key']._options = None
_REQUESTEDITPARAMETER.fields_by_name['value']._options = None
_REQUESTEDITPARAMETER.fields_by_name['clock']._options = None
_REQUESTEDITPARAMETER._options = None
_FEATUREFLAG.fields_by_name['key']._options = None
_FEATUREFLAG.fields_by_name['value']._options = None
_FEATUREFLAG.fields_by_name['clock']._options = None
_REQUESTFEATUREFLAGS._options = None
_RESPONSEFEATUREFLAGS._options = None
_UPDATEFEATUREFLAGCHANGED.fields_by_name['feature']._options = None
_UPDATEPARAMETERCHANGED.fields_by_name['key']._options = None
_UPDATEPARAMETERCHANGED.fields_by_name['value']._options = None

_CONFIGSYNC = _descriptor.ServiceDescriptor(
  name='ConfigSync',
  full_name='dialog.ConfigSync',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1105,
  serialized_end=1475,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetParameters',
    full_name='dialog.ConfigSync.GetParameters',
    index=0,
    containing_service=None,
    input_type=_REQUESTGETPARAMETERS,
    output_type=_RESPONSEGETPARAMETERS,
    serialized_options=b'\202\323\344\223\002&\"!/v1/grpc/ConfigSync/GetParameters:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditParameter',
    full_name='dialog.ConfigSync.EditParameter',
    index=1,
    containing_service=None,
    input_type=_REQUESTEDITPARAMETER,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002&\"!/v1/grpc/ConfigSync/EditParameter:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FeatureFlags',
    full_name='dialog.ConfigSync.FeatureFlags',
    index=2,
    containing_service=None,
    input_type=_REQUESTFEATUREFLAGS,
    output_type=_RESPONSEFEATUREFLAGS,
    serialized_options=b'\202\323\344\223\002%\" /v1/grpc/ConfigSync/FeatureFlags:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONFIGSYNC)

DESCRIPTOR.services_by_name['ConfigSync'] = _CONFIGSYNC

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integrations_pb2 as integrations__pb2


class IntegrationsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetIntegrationToken = channel.unary_unary(
                '/dialog.Integrations/GetIntegrationToken',
                request_serializer=integrations__pb2.RequestGetIntegrationToken.SerializeToString,
                response_deserializer=integrations__pb2.ResponseIntegrationToken.FromString,
                )
        self.RevokeIntegrationToken = channel.unary_unary(
                '/dialog.Integrations/RevokeIntegrationToken',
                request_serializer=integrations__pb2.RequestRevokeIntegrationToken.SerializeToString,
                response_deserializer=integrations__pb2.ResponseIntegrationToken.FromString,
                )


class IntegrationsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetIntegrationToken(self, request, context):
        """/ Get token for posting to group
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeIntegrationToken(self, request, context):
        """/ Revoke token
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IntegrationsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetIntegrationToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationToken,
                    request_deserializer=integrations__pb2.RequestGetIntegrationToken.FromString,
                    response_serializer=integrations__pb2.ResponseIntegrationToken.SerializeToString,
            ),
            'RevokeIntegrationToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeIntegrationToken,
                    request_deserializer=integrations__pb2.RequestRevokeIntegrationToken.FromString,
                    response_serializer=integrations__pb2.ResponseIntegrationToken.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Integrations', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Integrations(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetIntegrationToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Integrations/GetIntegrationToken',
            integrations__pb2.RequestGetIntegrationToken.SerializeToString,
            integrations__pb2.ResponseIntegrationToken.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevokeIntegrationToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Integrations/RevokeIntegrationToken',
            integrations__pb2.RequestRevokeIntegrationToken.SerializeToString,
            integrations__pb2.ResponseIntegrationToken.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
